@@ -20,6 +20,9 @@
 #ifndef __PYGOBJECT_BOXED_H__
 #define __PYGOBJECT_BOXED_H__
 
+#include <glib-object.h>
+#include <pythoncapi_compat.h>
+
 extern GQuark pygboxed_type_key;
 
 extern PyTypeObject PyGBoxed_Type;
