@@ -20,10 +20,9 @@
 #ifndef __PYGI_BOXED_H__
 #define __PYGI_BOXED_H__
 
-#include <girepository/girepository.h>
 #include <pythoncapi_compat.h>
 
-#include "pygobject-internal.h"
+#include "pygobject-types.h"
 
 G_BEGIN_DECLS
 
