@@ -26,8 +26,6 @@ extern GQuark pyginterface_info_key;
 
 extern PyTypeObject PyGInterface_Type;
 
-void pyg_register_interface (PyObject *dict, const gchar *class_name,
-                             GType gtype, PyTypeObject *type);
 const GInterfaceInfo *pyg_lookup_interface_info (GType gtype);
 void pyg_register_interface_info (GType gtype, const GInterfaceInfo *info);
 int pygi_interface_register_types (PyObject *d);
