@@ -620,6 +620,18 @@ class TestEverything(unittest.TestCase):
         with pytest.raises(UnicodeDecodeError):
             Everything.test_array_of_non_utf8_strings()
 
+    def test_array_callback(self):
+        TestCallbacks.called = 0
+
+        def callback(ints, ints_length, strings, strings_length):
+            self.assertEqual(ints, [-1, 0, 1, 2])
+            self.assertEqual(strings, ["one", "two", "three"])
+            TestCallbacks.called += 1
+            return TestCallbacks.called
+
+        Everything.test_array_callback(callback)
+        self.assertEqual(TestCallbacks.called, 2)
+
     def test_garray_container_return(self):
         # GPtrArray transfer container
         result = Everything.test_garray_container_return()
@@ -1367,7 +1379,6 @@ class TestBoxed(unittest.TestCase):
         self.assertEqual(obj.refcount, 2)
         del wrapper
         gc.collect()
-        gc.collect()
         self.assertEqual(obj.refcount, 1)
 
     def test_boxed_c_wrapper_copy(self):
@@ -1383,15 +1394,12 @@ class TestBoxed(unittest.TestCase):
         self.assertEqual(obj.refcount, 3)
         del wrapper
         gc.collect()
-        gc.collect()
         self.assertEqual(obj.refcount, 2)
         del wrapper_copy
         gc.collect()
-        gc.collect()
         self.assertEqual(obj.refcount, 1)
         del obj
         gc.collect()
-        gc.collect()
 
     def test_array_fixed_boxed_none_out(self):
         arr = Everything.test_array_fixed_boxed_none_out()
